@@ -5,13 +5,11 @@
 # @File    : __init__.py
 
 from .clifford_rz_optimization import CliffordRzOptimization
+from .commutative_optimization import CommutativeOptimization
 from .symbolic_clifford_optimization import SymbolicCliffordOptimization
 from .cnot_ancilla import CnotAncilla
-from .commutative_optimization import CommutativeOptimization
-from .cnot_local_force import (
-    CnotForceBfs, CnotForceDepthBfs,
-    CnotLocalForceBfs, CnotLocalForceDepthBfs,
-    CnotStoreForceBfs, CnotStoreForceDepthBfs
-)
+from .cnot_local_force import (CnotForceBfs, CnotForceDepthBfs,
+                               CnotLocalForceBfs, CnotLocalForceDepthBfs,
+                               CnotStoreForceBfs, CnotStoreForceDepthBfs)
 from .cnot_without_ancilla import CnotWithoutAncilla
 from .template_optimization import TemplateOptimization
