@@ -230,6 +230,7 @@ def u3_rule(gate):
     targ = gate.targ
     eps = 1e-6
 
+    # u3[0, 0] is real
     z = np.exp(1j * np.angle(unitary[0, 0]))
     unitary = unitary / z
 
@@ -242,6 +243,12 @@ def u3_rule(gate):
         lamda = 0
         phi = np.angle(unitary[1, 1] / np.cos(theta))
 
+    if _check2pi(theta, eps):
+        theta = 0
+    if _check2pi(lamda, eps):
+        lamda = 0
+    if _check2pi(phi, eps):
+        phi = 0
     g = build_gate(GateType.u3, targ, [theta * 2, phi, lamda])
     gates = CompositeGate(gates=[g])
     return gates
