@@ -15,6 +15,10 @@ from QuICT.core.utils import GateType, MatrixType
 from QuICT.ops.utils import LinAlgLoader
 from QuICT.ops.gate_kernel import float_multiply, complex_multiply
 from QuICT.simulation.utils import GateMatrixs
+from QuICT.tools.exception.core import ValueError, TypeError, GateQubitAssignedError
+from QuICT.tools.exception.simulation import (
+    SampleBeforeRunError, GateTypeNotImplementError, StateVectorUnmatchedError, GateAlgorithmNotImplementError
+)
 
 
 class ConstantStateVectorSimulator:
@@ -62,7 +66,7 @@ class ConstantStateVectorSimulator:
         sync: bool = True
     ):
         if precision not in self.__PRECISION:
-            raise ValueError("Wrong precision. Please use one of [single, double].")
+            raise ValueError("StateVectorSimulation.precision", "[single, double]", precision)
 
         self._precision = np.complex128 if precision == "double" else np.complex64
         self._device_id = gpu_device_id
@@ -82,7 +86,7 @@ class ConstantStateVectorSimulator:
         self._qubits = int(circuit.width())
         self._pipeline = []
 
-        if self._precision == np.complex64:
+        if self._precision != circuit._precision:
             circuit.convert_precision()
 
         self._pipeline = circuit.gates
@@ -110,7 +114,8 @@ class ConstantStateVectorSimulator:
         self,
         circuit: Circuit,
         state_vector: Union[np.ndarray, cp.ndarray] = None,
-        use_previous: bool = False
+        use_previous: bool = False,
+        gpu_out: bool = True
     ) -> np.ndarray:
         """ start simulator with given circuit
 
@@ -126,7 +131,7 @@ class ConstantStateVectorSimulator:
         self.initial_circuit(circuit)
         if state_vector is not None:
             assert 2 ** self._qubits == state_vector.size, \
-                "The state vector should has the same qubits with the circuit."
+                StateVectorUnmatchedError("The state vector should has the same qubits with the circuit.")
             self.vector = cp.array(state_vector, dtype=self._precision)
         elif not use_previous:
             self.initial_state_vector()
@@ -140,9 +145,12 @@ class ConstantStateVectorSimulator:
             elif isinstance(gate, Trigger):
                 self.apply_trigger(gate, idx)
             else:
-                raise TypeError(f"Unsupported circuit operator {type(gate)} in State Vector Simulator.")
+                raise TypeError("StateVectorSimulation.run.circuit", "[BasicGate, Trigger]". type(gate))
 
-        return self.vector
+        if not gpu_out:
+            return self.vector.get()
+        else:
+            return self.vector
 
     def apply_gate(self, gate: BasicGate):
         """ Depending on the given quantum gate, apply the target algorithm to calculate the state vector.
@@ -162,7 +170,7 @@ class ConstantStateVectorSimulator:
 
         # Deal with quantum gate with more than 3 qubits.
         if (
-            gate_type in [GateType.unitary, GateType.qft, GateType.iqft] and
+            gate_type in [GateType.unitary, GateType.qft, GateType.iqft, GateType.perm_fx] and
             gate.targets >= 3
         ):
             matrix = self._get_gate_matrix(gate)
@@ -177,13 +185,13 @@ class ConstantStateVectorSimulator:
 
             return
 
-        # [H, SX, SY, SW, U2, U3, Rx, Ry] 2-bits [CH, ] 2-bits[targets] [unitary]
+        # [H, Hy, SX, SY, SW, U2, U3, Rx, Ry] 2-bits [CH, ] 2-bits[Rzx, targets, unitary]
         if matrix_type == MatrixType.normal:
             self.apply_normal_matrix(gate)
-        # [Rz, Phase], 2-bits [CRz], 3-bits [CCRz]
+        # [Rz, Phase], 2-bits [CRz, Rzz], 3-bits [CCRz]
         elif matrix_type in [MatrixType.diagonal, MatrixType.diag_diag]:
             self.apply_diagonal_matrix(gate)
-        # [X] 2-bits [swap] 3-bits [CSWAP]
+        # [X] 2-bits [swap, iswap, iswapdg, sqiswap] 3-bits [CSWAP]
         elif matrix_type == MatrixType.swap:
             self.apply_swap_matrix(gate)
         # [Y] 2-bits [CX, CY] 3-bits: [CCX]
@@ -210,6 +218,15 @@ class ConstantStateVectorSimulator:
                 matrix,
                 *default_parameters
             )
+        # [Rzx]
+        elif matrix_type == MatrixType.diag_normal:
+            t_indexes = [self._qubits - 1 - targ for targ in gate.targs]
+            matrix = self._get_gate_matrix(gate)
+            self._algorithm.diagonal_normal_targs(
+                t_indexes,
+                matrix,
+                *default_parameters
+            )
         # [Measure, Reset]
         elif gate_type in [GateType.measure, GateType.reset]:
             index = self._qubits - 1 - gate.targ
@@ -234,11 +251,10 @@ class ConstantStateVectorSimulator:
             )
         # unsupported quantum gates
         else:
-            raise KeyError(f"Unsupported Gate: {gate_type}")
+            raise GateTypeNotImplementError(f"Unsupported Gate Type and Matrix Type: {gate_type} {matrix_type}.")
 
     def apply_normal_matrix(self, gate: BasicGate):
         # Get gate's parameters
-        assert gate.matrix_type == MatrixType.normal
         args_num = gate.controls + gate.targets
         gate_args = gate.cargs + gate.targs
         matrix = self._get_gate_matrix(gate)
@@ -270,11 +286,10 @@ class ConstantStateVectorSimulator:
                     *default_parameters
                 )
             else:
-                raise KeyError("Quantum gate cannot only have control qubits.")
+                raise GateQubitAssignedError("Quantum gate cannot only have control qubits.")
 
     def apply_diagonal_matrix(self, gate: BasicGate):
         # Get gate's parameters
-        assert gate.matrix_type in [MatrixType.diagonal, MatrixType.diag_diag]
         args_num = gate.controls + gate.targets
         gate_args = gate.cargs + gate.targs
         matrix = self._get_gate_matrix(gate)
@@ -306,8 +321,10 @@ class ConstantStateVectorSimulator:
                     *default_parameters
                 )
             else:
-                raise KeyError("Quantum gate cannot only have control qubits.")
+                raise GateQubitAssignedError("Quantum gate cannot only have control qubits.")
         else:   # [CCRz]
+            assert gate.type == GateType.ccrz, \
+                GateAlgorithmNotImplementError(f"State Vector Simulator cannot deal with {gate.type} currently.")
             c_indexes = [self._qubits - 1 - carg for carg in gate.cargs]
             t_index = self._qubits - 1 - gate.targ
             self._algorithm.diagonal_more(
@@ -319,7 +336,6 @@ class ConstantStateVectorSimulator:
 
     def apply_swap_matrix(self, gate: BasicGate):
         # Get gate's parameters
-        assert gate.matrix_type == MatrixType.swap
         args_num = gate.controls + gate.targets
         gate_args = gate.cargs + gate.targs
         default_parameters = (self._vector, self._qubits, self._sync)
@@ -331,12 +347,18 @@ class ConstantStateVectorSimulator:
                 *default_parameters
             )
         elif args_num == 2:     # Deal with Swap Gate
+            if gate.targets != 2:
+                raise GateAlgorithmNotImplementError(f"State Vector Simulator cannot deal with {gate.type} currently.")
+
             t_indexes = [self._qubits - 1 - targ for targ in gate_args]
             self._algorithm.swap_targs(
                 t_indexes,
+                self._get_gate_matrix(gate),
                 *default_parameters
             )
         else:   # CSwap
+            assert gate.type == GateType.cswap, \
+                GateAlgorithmNotImplementError(f"State Vector Simulator cannot deal with {gate.type} currently.")
             t_indexes = [self._qubits - 1 - targ for targ in gate.targs]
             c_index = self._qubits - 1 - gate.carg
             self._algorithm.swap_tmore(
@@ -347,7 +369,6 @@ class ConstantStateVectorSimulator:
 
     def apply_reverse_matrix(self, gate: BasicGate):
         # Get gate's parameters
-        assert gate.matrix_type == MatrixType.reverse
         args_num = gate.controls + gate.targets
         gate_args = gate.cargs + gate.targs
         matrix = self._get_gate_matrix(gate)
@@ -361,6 +382,9 @@ class ConstantStateVectorSimulator:
                 *default_parameters
             )
         elif args_num == 2:   # only consider 1 control qubit + 1 target qubit
+            if gate.targets == 2:
+                raise GateAlgorithmNotImplementError(f"State Vector Simulator cannot deal with {gate.type} currently.")
+
             c_index = self._qubits - 1 - gate_args[0]
             t_index = self._qubits - 1 - gate_args[1]
             self._algorithm.reverse_ctargs(
@@ -370,6 +394,8 @@ class ConstantStateVectorSimulator:
                 *default_parameters
             )
         else:   # CCX
+            assert gate.type == GateType.ccx, \
+                GateAlgorithmNotImplementError(f"State Vector Simulator cannot deal with {gate.type} currently.")
             c_indexes = [self._qubits - 1 - carg for carg in gate.cargs]
             t_index = self._qubits - 1 - gate.targ
             self._algorithm.reverse_more(
@@ -380,7 +406,6 @@ class ConstantStateVectorSimulator:
 
     def apply_control_matrix(self, gate: BasicGate):
         # Get gate's parameters
-        assert gate.matrix_type == MatrixType.control
         args_num = gate.controls + gate.targets
         gate_args = gate.cargs + gate.targs
         default_parameters = (self._vector, self._qubits, self._sync)
@@ -394,6 +419,9 @@ class ConstantStateVectorSimulator:
                 *default_parameters
             )
         elif args_num == 2:     # Deal with 2-qubit control gate, e.g. CZ
+            if gate.targets == 2:
+                raise GateAlgorithmNotImplementError(f"State Vector Simulator cannot deal with {gate.type} currently.")
+
             c_index = self._qubits - 1 - gate_args[0]
             t_index = self._qubits - 1 - gate_args[1]
             val = gate.matrix[3, 3]
@@ -403,6 +431,8 @@ class ConstantStateVectorSimulator:
                 val,
                 *default_parameters
             )
+        else:
+            raise GateAlgorithmNotImplementError(f"State Vector Simulator cannot deal with {gate.type} currently.")
 
     def apply_trigger(self, op: Trigger, current_idx: int) -> CompositeGate:
         """ Deal with the Operator <Trigger>.
@@ -448,7 +478,7 @@ class ConstantStateVectorSimulator:
         self._vector = cp.zeros_like(self.vector)
 
     def get_measured_prob(self, index: int, all_measured: bool = False) -> cp.ndarray:
-        """ Return the probability of measured qubit with given index to be 1
+        """ Return the probability of measured qubit with given index to be 0
 
         Args:
             index (int): The given qubit index
@@ -491,6 +521,8 @@ class ConstantStateVectorSimulator:
                 prob,
                 self._sync
             )
+        else:
+            raise ValueError("StateVectorSimulator.apply_specialgate", "[measure, reset]", type)
 
         return result
 
@@ -503,7 +535,8 @@ class ConstantStateVectorSimulator:
         Returns:
             List[int]: The measured result list with length equal to 2 ** self.qubits
         """
-        assert (self._circuit is not None)
+        assert (self._circuit is not None), \
+            SampleBeforeRunError("StateVectorSimulation sample without run any circuit.")
         original_sv = self._vector.copy()
         state_list = [0] * (1 << self._qubits)
         lastcall_per_qubit = self._circuit.get_lastcall_for_each_qubits()
