@@ -1,24 +1,6 @@
 from QuICT.tools.exception import QuICTException
 
 
-class CircuitTypeError(QuICTException):
-    """ Circuit Type Error, including Layout, Fidelity, Qureg, ... """
-    def __init__(self, msg: str = None):
-        super().__init__(1001, msg)
-
-
-class CircuitQubitsError(QuICTException):
-    """ Circuit's Qubits Error, including qubit index exceed or unmatched qureg. """
-    def __init__(self, msg: str = None):
-        super().__init__(1002, msg)
-
-
-class CircuitFidelityError(QuICTException):
-    """ Circuit Fidelity Error. """
-    def __init__(self, msg: str = None):
-        super().__init__(1003, msg)
-
-
 class CircuitAppendError(QuICTException):
     """ Circuit Append Operator Error. """
     def __init__(self, msg: str = None):
@@ -47,3 +29,10 @@ class CircuitDrawError(QuICTException):
     """ Circuit Draw Error. """
     def __init__(self, msg: str = None):
         super().__init__(1008, msg)
+
+
+class QASMError(QuICTException):
+    """ QASM Error. """
+    def __init__(self, other: str = None, line: str = None, file: str = None):
+        msg = "Qasm error:{} \n in line:{} \n error file:{}".format(other, line, file)
+        super().__init__(1009, msg)
